@@ -1,15 +1,14 @@
-callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plot=NULL) {
+callNCW <- function(title="",label,nperm = 10, seedn=100,stability=TRUE,plot=NULL) {
   #' Calculate normalized consensus weight(NCW) matrix based on permutation.
   #'
   #' @param title A character value for output directory. Directory is created only if not existed. This title can be an abosulte or relative path.
   #' @param label A matrix or data frame of input labels, columns=different clustering results and rows are samples.
   #' @param nperm A integer value of the permutation numbers, or nperm=10(default), which means \code{nperm}*1000 times of permutation.
-  #' @param ncore A integer value of cores to use, or ncore=1 (default). It's the input core numbers for the parallel computation in this package \code{parallel}.
   #' @param seedn A numerical value to set the start random seed for reproducible results, or seedn=100 (default). For every 1000 iteration, the seed will +1 to get repeat results.
   #' @param stability A logical value. Should estimate the stability of normalized consensus weight based on permutation numbers (default stability=TRUE), or not?
   #' @param plot character value. NULL(default) - print to screen, 'pdf', 'png', 'pngBMP' for bitmap png, helpful for large datasets, or 'pdf'. Input for \code{randConsensusMatrix}.
   #' @export
-  #' @import diceR parallel tidyr ggplot2
+  #' @import diceR tidyr ggplot2
   #' @return A matrix of normalized consensus weights.
   #' @examples
   #'
@@ -22,7 +21,7 @@ callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plo
   #'
   #' \donttest{
   #' # run ncw
-  #' ncw<-callNCW(title=title,label=label,stability=TRUE,nperm=4,ncore=1)
+  #' ncw<-callNCW(title=title,label=label,stability=TRUE,nperm=4)
   #' }
   #'
 
@@ -36,13 +35,19 @@ callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plo
 
 
   requireNamespace("diceR")
-  requireNamespace("parallel")
+  #requireNamespace("parallel")
   requireNamespace("tidyr")
   requireNamespace("ggplot2")
   # requireNamespace("ConsensusClusterPlus")
 
 
   # require(diceR); require(parallel); require(tidyr);require(ggplot2)
+  if(is.null(plot)==FALSE){
+    if(title==""){
+      stop("A 'title' of a character value for output directory must be provided when plot not NULL")
+    }
+
+  }
   if(missing(title)){
     stop("A 'title' of a character value for output directory must be provided") }
   if(!is.character(title)){
@@ -101,7 +106,7 @@ callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plo
   step = 1000 # number of random consensus weight matrix in each seed
 
   ## mc.cores, number of cores will be used
-  ncore = min(parallel::detectCores(),ncore)
+  ##ncore = min(parallel::detectCores(),ncore)
 
 
   ### number of non missing values for each column
@@ -143,8 +148,8 @@ callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plo
   ppath = paste0(title,"permutation/")
 
 
-  randL <- parallel::mclapply(seedL,function(x){randConsensusMatrix(l.seed=x,l.label=label,l.ns=ns,l.nc=nc,l.nv=nv,l.index=index,l.pair.ind=pair.ind,l.ppath=ppath,l.plot=plot)},mc.cores=ncore)
-
+  #randL <- parallel::mclapply(seedL,function(x){randConsensusMatrix(l.seed=x,l.label=label,l.ns=ns,l.nc=nc,l.nv=nv,l.index=index,l.pair.ind=pair.ind,l.ppath=ppath,l.plot=plot)},mc.cores=ncore)
+  randL<- lapply(seedL,function(x){randConsensusMatrix(l.seed=x,l.label=label,l.ns=ns,l.nc=nc,l.nv=nv,l.index=index,l.pair.ind=pair.ind,l.ppath=ppath,l.plot=plot)})
   ## calculate NCW----
   ### import all random consensus matrixes to randCM
 
@@ -223,7 +228,7 @@ callNCW <- function(title,label,nperm = 10, ncore=1,seedn=100,stability=TRUE,plo
         theme(axis.text.y.left = element_text(color = "blue"),plot.title = element_text(hjust = 0.5)))
 
     }else{
-      ggplot() +
+      p1<-ggplot() +
         geom_boxplot(pdata, mapping=aes(x=reps, y=diff2*sf,group=reps)) +
         geom_line(data=pdata2,aes(x=reps, y=y,group=1),color="blue") +
         geom_point(data=pdata2,aes(x=reps, y=y,group=1),size=3,shape=23,fill = "blue") +
